Test Verifications

Test for markup and newlines in text content.

Our rule for whitespace is that all non-visible whitespace (including &nbsp;) should be replaced with a single space, but all visible newlines (<br>, <p>, and <pre>formatted newlines) should be preserved.

Test Text Content
open | ../tests/html/test_text_content.html |
verifyText | nonTextMarkup | There is non-visible and visible markup here that doesn't change the text content
verifyText | spaces | exact:1 space|2 space|3 space|1 nbsp|2 nbsp|3 nbsp|2 space_nbsp|2 nbsp_space|3 space_nbsp_space|3 nbsp_space_nbsp
verifyText | tabcharacter | tab character between
verifyText | nonVisibleNewlines | non visible newlines between
verifyText | visibleNewlines | regexp:visible\s*newlines\s*between
verifyNotText | visibleNewlines | visible newlines between
verifyText | paragraphs | First paragraph*Second paragraph
verifyNotText | paragraphs | First paragraph Second paragraph
verifyText | preformatted | preformatted*newline
verifyNotText | preformatted | preformatted newline
verifyText | mixedMarkup | visible*newlines and markup and non-visible newlines and markup*With*a paragraph*and*pre*formatted*text